==============
Goal Champions
==============

Summary
-------

The OpenStack community is seeking coordinators for
the work to fulfill our :ref:`release-cycle-goals`.

Business Case
-------------

Organizations who sponsor Goal Champions
have someone in-house who understands the upstream decision making and
implementation work across services and projects.  This in-house
expertise can help minimize disruption to downstream products and
services and help position timely communications and expectations with
regard to upcoming changes.

Sponsors of Goal Champions are well-positioned to influence
decision-making not only the implementation choices meeting
community-wide initiatives, but also to help drive the choice and
rollout of upstream goals and use this influence to ensure that one's
own downstream products or deployments remain vital and targeted to
real use cases.

Sponsorship of a Goal Champion is a good way for an organisation to
demonstrate leadership across the whole of OpenStack, make a direct
impact on the productivity of other contributors, and build
influence among peers.  Goal Champions make great candidates for
future elected leadership positions in OpenStack.


.. _`backlog of potential goals`: https://etherpad.openstack.org/p/community-goals

Technical Details
-----------------

Each release series, the OpenStack Technical Committee selects a set
of shared objectives to be fulfilled in that release cycle, that
provide value across Openstack projects by e.g. advancing consistency
and user experience across OpenStack or addressing shared technical
debt.  These goals are selected from a `backlog of potential goals`_
based on feedback from deployers, users, contributors, and PTLs and
goal discussion during Forum events.

PTLs are responsible for ensuring that the work required to meet a
goal is completed within their own projects, but Goal Champions are
needed to guide, coordinate and track the work across projects.  A
Goal Champion needs a general understanding of the technical issues
involved in a goal, but primarily needs to communicate, track
progress, foster shared understanding across projects, and help remove
impediments.

Contact
-------

If possible, attend Forum and Summit sessions on series goals and
offer to sponsor a champion for a goal as part of the discussions at
these.  After these face to face events, discussion of goals continues
on the Technical Committee IRC channel (``#openstack-tc`` on `OFTC
<https://www.oftc.net>`_) and on the OpenStack-discuss `mailing list`_
using the ``[goals]`` tag in the subject line.

.. _`mailing list`: http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss
